Redis High-Level Interface

hi(...)

Arguments

...

Arguments passed on to redux::hiredis

version

Version of the interface to generate. If given as a string to numeric version, then only commands that exist up to that version will be included. If given as TRUE, then we will query the Redis server (with INFO) and extract the version number that way.

Value

Redis interface facade, R6 redis_api instance

Examples

if (FALSE) {
redis <- redisr::hi()
redis$PING()
#> [Redis: PONG]
}