Reads All Package-Installed Lua Scripts

read.inst_lua(..., package = "redisr")

Arguments

...

Script base-name filters; reads all scripts if no filters

package

Name of installed package

Value

Named list of character vectors after reading the package-installed Lua scripts. The names exclude the package path and the lua

file-name extension.