read.inst_lua.RdReads All Package-Installed Lua Scripts
read.inst_lua(..., package = "redisr")Script base-name filters; reads all scripts if no filters
Name of installed package
Named list of character vectors after reading the package-installed
Lua scripts. The names exclude the package path and the lua
file-name extension.