script_load.evalsha.RdLoad and Evaluate Scripts by SHA
script_load.evalsha(named_scripts, redis = hi(), ...)Named list of Lua scripts
High-level Redis interface
Arguments passed on to scripts
xRedis high-level interface
SHA evaluate function accepting script name, key vector and argument vector in that order; the name becomes the Lua script SHA by look-up
Redux decodes a Redis reply as a raw vector if the first two
characters match X or B followed by new-line. Raw vector replies then
answer if the remaining bytes contain at least one null, a zero byte. See
the implementation of the C function is_raw_string in the
redux package for more details.